@@ -460,85 +460,6 @@ eel_bonobo_make_registration_id (const char *iid)
 		iid, DisplayString (gdk_display));
 }
 
-static ORBit_IMethod *
-get_set_value_imethod (void)
-{
-	static ORBit_IMethod *imethod = NULL;
-
-	if (!imethod) {
-		guint i;
-		ORBit_IMethods *methods;
-
-		methods = &Bonobo_PropertyBag__iinterface.methods;
-
-		for (i = 0; i < methods->_length; i++) {
-			if (!strcmp (methods->_buffer [i].name,
-				     "setValue"))
-				imethod = &methods->_buffer [i];
-		}
-		g_assert (imethod != NULL);
-	}
-
-	return imethod;
-}
-
-static void
-do_nothing_cb (CORBA_Object          object,
-	       ORBit_IMethod        *m_data,
-	       ORBitAsyncQueueEntry *aqe,
-	       gpointer              user_data, 
-	       CORBA_Environment    *ev)
-{
-	/* FIXME: we can remove this when people
-	   have the fixed ORB more prevelantly */
-}
-
-/**
- * eel_bonobo_pbclient_set_value_async:
- * @bag: a reference to the PropertyBag
- * @key: key of the value to set
- * @value: the new value
- * @opt_ev: an optional CORBA_Environment to return failure codes
- *
- * Set a value on the PropertyBag asynchronously, discarding any
- * possible roundtrip exceptions.
- */
-void
-eel_bonobo_pbclient_set_value_async (Bonobo_PropertyBag  bag,
-				     const char         *key,
-				     CORBA_any          *value,
-				     CORBA_Environment  *opt_ev)
-{
-	gpointer args [2];
-	CORBA_Environment ev, *my_ev;
-
-	g_return_if_fail (key != NULL);
-	g_return_if_fail (value != NULL);
-	g_return_if_fail (bag != CORBA_OBJECT_NIL);
-
-	if (!opt_ev) {
-		CORBA_exception_init (&ev);
-		my_ev = &ev;
-	} else
-		my_ev = opt_ev;
-
-	if (BONOBO_EX (my_ev) || bag == CORBA_OBJECT_NIL) {
-		if (!opt_ev)
-			CORBA_exception_free (&ev);
-		return;
-	}
-
-	args [0] = (gpointer) &key;
-	args [1] = (gpointer) value;
-
-	ORBit_small_invoke_async
-		(bag, get_set_value_imethod (),
-		 do_nothing_cb, NULL, args, NULL, my_ev);
-	
-	if (!opt_ev)
-		CORBA_exception_free (&ev);
-}
-
 /**
  * eel_glade_get_file:
  * @filename: the XML file name.
